.. _Reporting:

Bug reports, questions, discussion, new features
------------------------------------------------

- If you spotted **a bug**, please file a precise bug report
  `on GitHub <https://github.com/noripyt/django-cachalot/issues>`_
- If you have **a question** on how django-cachalot works
  or to **simply discuss**,
  `chat with us on Discord <https://discord.gg/WFGFBk8rSU>`_.
- If you want **to add a feature**:

  - if you have an idea on how to implement it, you can fork the project
    and send a pull request, but **please open an issue first**, because
    someone else could already be working on it
  - if you’re sure that it’s a must-have feature, open an issue
  - if it’s just a vague idea, please
    `ask on Discord <https://discord.gg/WFGFBk8rSU>`_ first
